# coding: utf-8

"""
    Taurus Data Jobs

    The Taurus Data Jobs internal and Control Plane API. Data Jobs allows Data Engineers to implement automated pull ingestion (E in ELT) and batch data transformation into Data Warehouse (T in ELT). See also https://github.com/vmware/versatile-data-kit/wiki/Introduction  The API has resource-oriented URLs, JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. The API enables creating, deploying, managing and executing Data Jobs in runtime environment.<br> <br> The API reflects the usual Data Job Development lifecycle:<br> <li> Create a new data job (webhook to further configure job -e.g authorize its createion, setup permissions, etc). <li> Download keytab. Develop and run the data job locally. <li> Deploy data job in cloud runtime enviornment to run on scheduled basis. <br><br> If Authentication is required pass OAuth2 access token in http header 'Authorization: Bearer [access-token-here]'  The API promotes some best practices (inspired by https://12factor.net ): <li> Explicitly declare and isolate dependencies <li> Strict separation of config from code. Config varies substantially across deploys, code does not. <li> Separation between the build, release/deploy, and run stages <li> Data Jobs are stateless and share-nothing processes. Any data that needs to persist must be stored in a stateful backing service (e.g IProperties). <li> Implementation is assumed to be be atomic and idempotent - should be OK for a job to fail somewhere in the middle; subsequent restart should not cause data corruption. <li> Keep development, staging, and production as similar as possible <br><br> <b>API Evolution</b><br> In the following sections, there are some terms that have a special meaning in the context of the APIs. <br><br> <li> <i>Stable</i> - The implementation of API has been battle-tested (has been in production for some time - probably at least a month)                      API is subject to the semantic versioning model and will follow                      deprecation policy <li> <i>Experimental</i> - May disappear without notice and is not subject to semantic versioning                            Implementation of the API is not considered stable nor well tested.                            Generally this is given to clients to experiment within testing environment. Must not be used in Production. <li> <i>Deprecated</i> - API is expected to be removed within next one or two major version upgrade.                          The deprecation notice/comment will say when the API will be removed and what alternatives should be used instead.   # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from taurus_datajob_api.configuration import Configuration


class DataJobDeploymentStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'vdk_version': 'str',
        'job_version': 'str',
        'mode': 'DataJobMode',
        'id': 'str',
        'enabled': 'bool',
        'contacts': 'DataJobContacts',
        'schedule': 'DataJobSchedule',
        'resources': 'DataJobResources',
        'last_deployed_date': 'str',
        'last_deployed_by': 'str'
    }

    attribute_map = {
        'vdk_version': 'vdk_version',
        'job_version': 'job_version',
        'mode': 'mode',
        'id': 'id',
        'enabled': 'enabled',
        'contacts': 'contacts',
        'schedule': 'schedule',
        'resources': 'resources',
        'last_deployed_date': 'last_deployed_date',
        'last_deployed_by': 'last_deployed_by'
    }

    def __init__(self, vdk_version=None, job_version=None, mode=None, id=None, enabled=True, contacts=None, schedule=None, resources=None, last_deployed_date='null', last_deployed_by='null', local_vars_configuration=None):  # noqa: E501
        """DataJobDeploymentStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._vdk_version = None
        self._job_version = None
        self._mode = None
        self._id = None
        self._enabled = None
        self._contacts = None
        self._schedule = None
        self._resources = None
        self._last_deployed_date = None
        self._last_deployed_by = None
        self.discriminator = None

        if vdk_version is not None:
            self.vdk_version = vdk_version
        if job_version is not None:
            self.job_version = job_version
        if mode is not None:
            self.mode = mode
        if id is not None:
            self.id = id
        if enabled is not None:
            self.enabled = enabled
        if contacts is not None:
            self.contacts = contacts
        if schedule is not None:
            self.schedule = schedule
        if resources is not None:
            self.resources = resources
        if last_deployed_date is not None:
            self.last_deployed_date = last_deployed_date
        if last_deployed_by is not None:
            self.last_deployed_by = last_deployed_by

    @property
    def vdk_version(self):
        """Gets the vdk_version of this DataJobDeploymentStatus.  # noqa: E501

        A specific VDK version to use.  # noqa: E501

        :return: The vdk_version of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: str
        """
        return self._vdk_version

    @vdk_version.setter
    def vdk_version(self, vdk_version):
        """Sets the vdk_version of this DataJobDeploymentStatus.

        A specific VDK version to use.  # noqa: E501

        :param vdk_version: The vdk_version of this DataJobDeploymentStatus.  # noqa: E501
        :type: str
        """

        self._vdk_version = vdk_version

    @property
    def job_version(self):
        """Gets the job_version of this DataJobDeploymentStatus.  # noqa: E501

        Job version (can be git commit).  # noqa: E501

        :return: The job_version of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: str
        """
        return self._job_version

    @job_version.setter
    def job_version(self, job_version):
        """Sets the job_version of this DataJobDeploymentStatus.

        Job version (can be git commit).  # noqa: E501

        :param job_version: The job_version of this DataJobDeploymentStatus.  # noqa: E501
        :type: str
        """

        self._job_version = job_version

    @property
    def mode(self):
        """Gets the mode of this DataJobDeploymentStatus.  # noqa: E501


        :return: The mode of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: DataJobMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this DataJobDeploymentStatus.


        :param mode: The mode of this DataJobDeploymentStatus.  # noqa: E501
        :type: DataJobMode
        """

        self._mode = mode

    @property
    def id(self):
        """Gets the id of this DataJobDeploymentStatus.  # noqa: E501

        String that identifies a single deployment of a Data Job. Currently only single deployment per Data Job is possible. In the future: It's recommended to use following ids - development, testing, production. But users are free to come up with their own. For example - this enables create with same Data Job code 3 different deployment: development  deployment  --deployment-id development testing deployment  --deployment-id testing production deployment  --deployment-id prod   # noqa: E501

        :return: The id of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DataJobDeploymentStatus.

        String that identifies a single deployment of a Data Job. Currently only single deployment per Data Job is possible. In the future: It's recommended to use following ids - development, testing, production. But users are free to come up with their own. For example - this enables create with same Data Job code 3 different deployment: development  deployment  --deployment-id development testing deployment  --deployment-id testing production deployment  --deployment-id prod   # noqa: E501

        :param id: The id of this DataJobDeploymentStatus.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def enabled(self):
        """Gets the enabled of this DataJobDeploymentStatus.  # noqa: E501

        Enable/disable flag.  # noqa: E501

        :return: The enabled of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DataJobDeploymentStatus.

        Enable/disable flag.  # noqa: E501

        :param enabled: The enabled of this DataJobDeploymentStatus.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def contacts(self):
        """Gets the contacts of this DataJobDeploymentStatus.  # noqa: E501


        :return: The contacts of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: DataJobContacts
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this DataJobDeploymentStatus.


        :param contacts: The contacts of this DataJobDeploymentStatus.  # noqa: E501
        :type: DataJobContacts
        """

        self._contacts = contacts

    @property
    def schedule(self):
        """Gets the schedule of this DataJobDeploymentStatus.  # noqa: E501


        :return: The schedule of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: DataJobSchedule
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this DataJobDeploymentStatus.


        :param schedule: The schedule of this DataJobDeploymentStatus.  # noqa: E501
        :type: DataJobSchedule
        """

        self._schedule = schedule

    @property
    def resources(self):
        """Gets the resources of this DataJobDeploymentStatus.  # noqa: E501


        :return: The resources of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: DataJobResources
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this DataJobDeploymentStatus.


        :param resources: The resources of this DataJobDeploymentStatus.  # noqa: E501
        :type: DataJobResources
        """

        self._resources = resources

    @property
    def last_deployed_date(self):
        """Gets the last_deployed_date of this DataJobDeploymentStatus.  # noqa: E501

        The date and time in UTC of last deployment of the data job deployment.  # noqa: E501

        :return: The last_deployed_date of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: str
        """
        return self._last_deployed_date

    @last_deployed_date.setter
    def last_deployed_date(self, last_deployed_date):
        """Sets the last_deployed_date of this DataJobDeploymentStatus.

        The date and time in UTC of last deployment of the data job deployment.  # noqa: E501

        :param last_deployed_date: The last_deployed_date of this DataJobDeploymentStatus.  # noqa: E501
        :type: str
        """

        self._last_deployed_date = last_deployed_date

    @property
    def last_deployed_by(self):
        """Gets the last_deployed_by of this DataJobDeploymentStatus.  # noqa: E501

        The username of the user who modified the data job last.  # noqa: E501

        :return: The last_deployed_by of this DataJobDeploymentStatus.  # noqa: E501
        :rtype: str
        """
        return self._last_deployed_by

    @last_deployed_by.setter
    def last_deployed_by(self, last_deployed_by):
        """Sets the last_deployed_by of this DataJobDeploymentStatus.

        The username of the user who modified the data job last.  # noqa: E501

        :param last_deployed_by: The last_deployed_by of this DataJobDeploymentStatus.  # noqa: E501
        :type: str
        """

        self._last_deployed_by = last_deployed_by

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DataJobDeploymentStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DataJobDeploymentStatus):
            return True

        return self.to_dict() != other.to_dict()
